pub struct DebugRenderer {
font_vertices: Vec<DebugFontVertex>,
font_indices: Vec<u32>,
font_program: Program,
font_vao: VAO,
font_texture: Texture,
tri_vertices: Vec<DebugColorVertex>,
tri_indices: Vec<u32>,
tri_vao: VAO,
line_vertices: Vec<DebugColorVertex>,
line_vao: VAO,
color_program: Program,
}Fields
font_vertices: Vec<DebugFontVertex>font_indices: Vec<u32>font_program: Programfont_vao: VAOfont_texture: Texturetri_vertices: Vec<DebugColorVertex>tri_indices: Vec<u32>tri_vao: VAOline_vertices: Vec<DebugColorVertex>line_vao: VAOcolor_program: ProgramImplementations
Sourceimpl DebugRenderer
impl DebugRenderer
pub fn new(device: &mut Device) -> Result<Self, ShaderError>
pub fn deinit(self, device: &mut Device)
pub fn line_height(&self) -> f32
Sourcepub fn add_text(
&mut self,
x: f32,
y: f32,
text: &str,
color: ColorU,
bounds: Option<DeviceRect>,
) -> Rect<f32>
pub fn add_text( &mut self, x: f32, y: f32, text: &str, color: ColorU, bounds: Option<DeviceRect>, ) -> Rect<f32>
Draws a line of text at the provided starting coordinates.
If |bounds| is specified, glyphs outside the bounds are discarded.
Y-coordinates is relative to screen top, along with everything else in this file.
pub fn add_quad( &mut self, x0: f32, y0: f32, x1: f32, y1: f32, color_top: ColorU, color_bottom: ColorU, )
pub fn add_line( &mut self, x0: i32, y0: i32, color0: ColorU, x1: i32, y1: i32, color1: ColorU, )
pub fn add_rect(&mut self, rect: &DeviceIntRect, thickness: i32, color: ColorU)
pub fn render( &mut self, device: &mut Device, viewport_size: Option<DeviceIntSize>, scale: f32, surface_origin_is_top_left: bool, )